@@ -7,8 +7,9 @@ LastEditTime: 2022.02.10 14:54
 import os.path
 import time
 from pathlib import Path
-from typing import List, Tuple
+from typing import Dict, List, Tuple
 
+import click
 from jinja2 import Template
 
 from .common import (
@@ -41,7 +42,8 @@ def render_templates_recursively(
     src: Path = None,
     render=render_by_jinja2,
     only_files: Tuple[str] = None,
-    **kwargs
+    replace_list: dict = None,
+    **kwargs,
 ):
     src = src or p
     q = dst / (p.relative_to(src))
@@ -69,11 +71,13 @@ def render_templates_recursively(
                 include_suffixes=include_suffixes,
                 src=p,
                 only_files=only_files,
-                **kwargs
+                **kwargs,
             )
 
     elif p.is_file():
-        if only_files and p.stem not in only_files:
+        if only_files and (
+            p.stem.lower() not in only_files and p.name.lower() not in only_files
+        ):
             return
 
         suffixes = p.suffixes
@@ -97,8 +101,17 @@ def render_templates_recursively(
             return
 
         kwargs["GOLANG_PACKAGE"] = p.parent.stem
-        content = render(p.open(encoding="utf-8").read(), **kwargs)
-        q.open("w", encoding="utf-8", newline="\n").write(content)
+
+        try:
+            content = render(p.open(encoding="utf-8").read(), **kwargs)
+            if replace_list:
+                for k, v in replace_list.items():
+                    content.replace(k, v)
+            q.open("w", encoding="utf-8", newline="\n").write(content)
+        except UnicodeDecodeError:
+            q.write_bytes(p.read_bytes())
+
+        click.echo(f"created: {q.relative_to(Path.cwd())}")
 
 
 def render_templates(
@@ -107,8 +120,9 @@ def render_templates(
     include_suffixes: List[str] = None,
     folders: List[str] = None,
     common: bool = True,
-    only_files: List[str] = None,
-    **kwargs
+    only_files: str = "",
+    replace_list: dict = None,
+    **kwargs,
 ):
     package, package_title, package_underscore = get_different_camel_case_styles()
 
@@ -117,7 +131,8 @@ def render_templates(
         Path.cwd(),
         special_paths=special_paths,
         include_suffixes=include_suffixes,
-        only_files=only_files,
+        only_files=only_files.lower().split(";") if only_files else None,
+        replace_list=replace_list,
         **{
             "STUDY_OBJECT": package_title,
             "PACKAGE_TITLE": package_title,
@@ -126,10 +141,11 @@ def render_templates(
             "GOLANG_MODULE": package,
             "PYPI_PACKAGE": package,
             "PYTHON_MODULE": package_underscore,
-            "MAKEFILE_HEADER": GENERATOR_HEADER,
+            "HASHTAG_COMMENTS": GENERATOR_HEADER,
+            "SLASH_COMMENTS": GENERATOR_HEADER.replace("#", "//"),
             "CREATED_AT": time.strftime("%Y-%m-%dT%H:%M:%S+08:00"),
             **kwargs,
-        }
+        },
     )
 
     if common:
